# leaderbird
For leaderboards and rankings.

## Overview
Helper library for leaderboards and rankings, such as ELO-based rankings between humans, AI's, and between humans and AI's.

## Rules
1. Don't let the code get sloppy.
